Module: Bicho
- Defined in:
- lib/bicho.rb,
lib/bicho/bug.rb,
lib/bicho/query.rb,
lib/bicho/export.rb,
lib/bicho/history.rb,
lib/bicho/logging.rb,
lib/bicho/reports.rb,
lib/bicho/version.rb,
lib/bicho/attachment.rb,
lib/bicho/cli/command.rb,
lib/bicho/plugins/user.rb,
lib/bicho/common_client.rb,
lib/bicho/plugins/novell.rb,
lib/bicho/plugins/aliases.rb,
lib/bicho/cli/commands/reopen.rb,
lib/bicho/client.rb
Overview
All classes go into this module.
Defined Under Namespace
Modules: CLI, CommonClient, Export, Logging, Plugins, Reports Classes: Attachment, Bug, Change, ChangeSet, Client, History, LoggerIODevice, Query
Constant Summary collapse
- SEARCH_FIELDS =
[ # name, type, description, multi [:alias, :strings, 'The unique alias for this bug', true], [:assigned_to, :strings, 'The login name of a user that a bug is assigned to.', true], [:component, :strings, 'The name of the Component', true], [:creation_time, :string, 'Searches for bugs that were created at this time or later.', false], [:id, :ints, 'The numeric id of the bug.', true], [:last_change_time, :string, 'Searches for bugs that were modified at this time or later.', false], [:limit, :ints, 'Limit the number of results returned to int records.', true], [:offset, :ints, 'Used in conjunction with the limit argument, offset defines the starting position for the search.', true], [:op_sys, :strings, "The 'Operating System' field of a bug.", true], [:platform, :strings, 'The Platform field of a bug.', true], [:priority, :strings, 'The Priority field on a bug.', true], [:product, :strings, 'The name of the Product that the bug is in.', true], [:reporter, :strings, 'The login name of the user who reported the bug.', true], [:resolution, :strings, 'The current resolution--only set if a bug is closed.', true], [:severity, :strings, 'The Severity field on a bug.', true], [:status, :strings, 'The current status of a bug', true], [:summary, :strings, 'Searches for substrings in the single-line Summary field on bugs.', true], [:target_milestone, :strings, 'The Target Milestone field of a bug.', true], [:qa_contact, :strings, "The login name of the bug's QA Contact.", true], [:url, :strings, "The 'URL' field of a bug.", true], [:version, :strings, 'The Version field of a bug.', true], [:votes, :ints, 'Searches for bugs with this many votes or greater', false], [:whiteboard, :strings, "Search the 'Status Whiteboard' field on bugs for a substring.", true] ].freeze
- VERSION =
'0.0.18'
Class Method Summary collapse
-
.client ⇒ Object
Current client used by the library.
-
.client=(client) ⇒ Object
Sets the common client to be used by the library.
Class Method Details
.client ⇒ Object
Current client used by the library
56 57 58 |
# File 'lib/bicho/common_client.rb', line 56 def self.client CommonClient.common_client end |
.client=(client) ⇒ Object
Sets the common client to be used by the library
51 52 53 |
# File 'lib/bicho/common_client.rb', line 51 def self.client=(client) CommonClient.common_client = client end |